==> cutetube_1.7.1.tar.gz: cutetube-1.7.1/cutetubeapp/src/maemo5_gui/dailymotionuserlistdelegate.cpp <==
#include "dailymotionuserlistdelegate.h"
#include "../base/abstractuserlistmodel.h"
#include <QApplication>
#include <QPainter>

DailymotionUserListDelegate::DailymotionUserListDelegate(QObject *parent) :
    QStyledItemDelegate(parent)
{
}

void DailymotionUserListDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const {
    painter->save();

    if ((option.state) & (QStyle::State_Selected)) {
        painter->drawImage(option.rect, QImage("/etc/hildon/theme/images/TouchListBackgroundPressed.png"));
    }
    else {
        painter->drawImage(option.rect, QImage("/etc/hildon/theme/images/TouchListBackgroundNormal.png"));
    }

    QRect imageRect = option.rect;
    imageRect.moveTopLeft(QPoint(imageRect.left() + 5, imageRect.top() + 5));
    imageRect.setSize(QSize(60, 60));

    QImage image = index.data(AbstractUserListModel::AvatarRole).value<QImage>();

    if (!image.isNull()) {
        painter->drawImage(imageRect, image);
    }

    painter->setPen(QColor("#4d4d4d"));
    painter->drawRect(imageRect);
    painter->setPen(Qt::white);

    QRect textRect = option.rect;
    textRect.setTopLeft(QPoint(imageRect.right() + 5, imageRect.top()));
    textRect.setRight(textRect.right() - 5);
    textRect.setHeight(60);

    painter->drawText(textRect, Qt::TextWordWrap, index.data(AbstractUserListModel::UsernameRole).toString());

    textRect.moveTop(textRect.bottom() + 5);

    QFont smallFont;
    smallFont.setPixelSize(18);
    painter->setFont(smallFont);

    int videoCount = index.data(AbstractUserListModel::ViewCountRole).toInt();

    painter->drawText(textRect, !videoCount ? tr("No views") : QString("%1 %2").arg(videoCount).arg(tr("views")));
    painter->restore();
}

QSize DailymotionUserListDelegate::sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const {
    Q_UNUSED(index)

    return QSize(option.rect.width(), 100);
}

==> cutetube_1.7.3.tar.gz: cutetube-1.7.3/cutetubeapp/src/maemo5_gui/dailymotionuserlistdelegate.cpp <==
#include "dailymotionuserlistdelegate.h"
#include "../base/abstractuserlistmodel.h"
#include <QApplication>
#include <QPainter>

DailymotionUserListDelegate::DailymotionUserListDelegate(QObject *parent) :
    QStyledItemDelegate(parent)
{
}

void DailymotionUserListDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const {
    painter->save();

    if ((option.state) & (QStyle::State_Selected)) {
        painter->drawImage(option.rect, QImage("/etc/hildon/theme/images/TouchListBackgroundPressed.png"));
    }
    else {
        painter->drawImage(option.rect, QImage("/etc/hildon/theme/images/TouchListBackgroundNormal.png"));
    }

    QRect imageRect = option.rect;
    imageRect.moveTopLeft(QPoint(imageRect.left() + 5, imageRect.top() + 5));
    imageRect.setSize(QSize(60, 60));

    QImage image = index.data(AbstractUserListModel::AvatarRole).value<QImage>();

    if (!image.isNull()) {
        painter->drawImage(imageRect, image);
    }

    painter->setPen(QColor("#4d4d4d"));
    painter->drawRect(imageRect);
    painter->setPen(Qt::white);

    QRect textRect = option.rect;
    textRect.setTopLeft(QPoint(imageRect.right() + 5, imageRect.top()));
    textRect.setRight(textRect.right() - 5);
    textRect.setHeight(60);

    painter->drawText(textRect, Qt::TextWordWrap | Qt::AlignVCenter, index.data(AbstractUserListModel::UsernameRole).toString());
    painter->restore();
}

QSize DailymotionUserListDelegate::sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const {
    Q_UNUSED(index)

    return QSize(option.rect.width(), 70);
}
